@@ -8,16 +8,17 @@ from EasyMLLib.helper import Helper
 OUTPUT_FOLDER_PATH = path.join("Outputs", "Output")
 
 class CSVWriter:
-    def __init__(self, name: string, columns: List[str]):
+    def __init__(self, name: string, columns: List[str], outputpath=OUTPUT_FOLDER_PATH):
         self.name = name
         self.columns = columns
-        Helper().createPath(OUTPUT_FOLDER_PATH)
-        with open(path.join(OUTPUT_FOLDER_PATH, self.name), "a+", newline='') as file:
+        self.outputpath = outputpath
+        Helper().createPath(outputpath)
+        with open(path.join(outputpath, self.name), "a+", newline='') as file:
                 writerObj = writer(file)
                 writerObj.writerow(columns)
-        
-        
+
+
     def addRow(self, row: list):
-        with open(path.join(OUTPUT_FOLDER_PATH, self.name), "a+", newline='') as file:
+        with open(path.join(self.outputpath, self.name), "a+", newline='') as file:
             writerObj = writer(file)
-            writerObj.writerow(row)
\ No newline at end of file
+            writerObj.writerow(row)
